@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/domain.c
  *
- * Copyright (C) 2005-2011  NTT DATA CORPORATION
+ * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.7.3+   2011/05/05
+ * Version: 1.7.3+   2012/05/05
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -1130,11 +1130,19 @@ bool ccs_dump_page(struct linux_binprm *bprm, unsigned long pos,
 		 * But remove_arg_zero() uses kmap_atomic()/kunmap_atomic().
 		 * So do I.
 		 */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 37)
+		char *kaddr = kmap_atomic(page);
+#else
 		char *kaddr = kmap_atomic(page, KM_USER0);
+#endif
 		dump->page = page;
 		memcpy(dump->data + offset, kaddr + offset,
 		       PAGE_SIZE - offset);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 37)
+		kunmap_atomic(kaddr);
+#else
 		kunmap_atomic(kaddr, KM_USER0);
+#endif
 	}
 	/* Same with put_arg_page(page) in fs/exec.c */
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) && defined(CONFIG_MMU)
